/*
 * Customer.java
 *
 * Created on 5. Dezember 2006, 11:29
 *
 * To change this template, choose Tools | Template Manager
 * and open the template in the editor.
 */

package de.vullriede.lazyLoading.model;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Collection;
import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.Id;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.OneToMany;
import javax.persistence.Table;

/**
 * Entity class Customer
 * 
 * @author g040037
 */
@Entity
@Table(name = "CUSTOMER")
@NamedQueries( {
        @NamedQuery(name = "Customer.findById", query = "SELECT c FROM Customer c WHERE c.id = :id"),
        @NamedQuery(name = "Customer.findByName", query = "SELECT c FROM Customer c WHERE c.name = :name")
    })
public class Customer implements Serializable {

    @Id
    @Column(name = "ID", nullable = false)
    private BigDecimal id;

    @Column(name = "NAME", nullable = false)
    private String name;

    @OneToMany(cascade = CascadeType.ALL, mappedBy = "customer", fetch = FetchType.LAZY)
    private Collection<Location> locationCollection;
    
    /** Creates a new instance of Customer */
    public Customer() {
    }

    /**
     * Creates a new instance of Customer with the specified values.
     * @param id the id of the Customer
     */
    public Customer(BigDecimal id) {
        this.id = id;
    }

    /**
     * Creates a new instance of Customer with the specified values.
     * @param id the id of the Customer
     * @param name the name of the Customer
     */
    public Customer(BigDecimal id, String name) {
        this.id = id;
        this.name = name;
    }

    /**
     * Gets the id of this Customer.
     * @return the id
     */
    public BigDecimal getId() {
        return this.id;
    }

    /**
     * Sets the id of this Customer to the specified value.
     * @param id the new id
     */
    public void setId(BigDecimal id) {
        this.id = id;
    }

    /**
     * Gets the name of this Customer.
     * @return the name
     */
    public String getName() {
        return this.name;
    }

    /**
     * Sets the name of this Customer to the specified value.
     * @param name the new name
     */
    public void setName(String name) {
        this.name = name;
    }

    /**
     * Gets the locationCollection of this Customer.
     * @return the locationCollection
     */
    public Collection<Location> getLocationCollection() {
        return this.locationCollection;
    }

    /**
     * Sets the locationCollection of this Customer to the specified value.
     * @param locationCollection the new locationCollection
     */
    public void setLocationCollection(Collection<Location> locationCollection) {
        this.locationCollection = locationCollection;
    }

    /**
     * Returns a hash code value for the object.  This implementation computes 
     * a hash code value based on the id fields in this object.
     * @return a hash code value for this object.
     */
    @Override
    public int hashCode() {
        int hash = 0;
        hash += (this.id != null ? this.id.hashCode() : 0);
        return hash;
    }

    /**
     * Determines whether another object is equal to this Customer.  The result is 
     * <code>true</code> if and only if the argument is not null and is a Customer object that 
     * has the same id field values as this object.
     * @param object the reference object with which to compare
     * @return <code>true</code> if this object is the same as the argument;
     * <code>false</code> otherwise.
     */
    @Override
    public boolean equals(Object object) {
        // TODO: Warning - this method won't work in the case the id fields are not set
        if (!(object instanceof Customer)) {
            return false;
        }
        Customer other = (Customer)object;
        if (this.id != other.id && (this.id == null || !this.id.equals(other.id))) return false;
        return true;
    }

    /**
     * Returns a string representation of the object.  This implementation constructs 
     * that representation based on the id fields.
     * @return a string representation of the object.
     */
    @Override
    public String toString() {
        return "de.vullriede.lazyLoading.model.Customer[id=" + id + "]";
    }
    
}
