/*
 * Location.java
 *
 * Created on 5. Dezember 2006, 11:29
 *
 * To change this template, choose Tools | Template Manager
 * and open the template in the editor.
 */

package de.vullriede.lazyLoading.model;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Collection;
import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.OneToMany;
import javax.persistence.Table;

/**
 * Entity class Location
 * 
 * @author g040037
 */
@Entity
@Table(name = "LOCATION")
@NamedQueries( {
        @NamedQuery(name = "Location.findById", query = "SELECT l FROM Location l WHERE l.id = :id"),
        @NamedQuery(name = "Location.findByName", query = "SELECT l FROM Location l WHERE l.name = :name")
    })
public class Location implements Serializable {

    @Id
    @Column(name = "ID", nullable = false)
    private BigDecimal id;

    @Column(name = "NAME", nullable = false)
    private String name;

    @OneToMany(cascade = CascadeType.ALL, mappedBy = "location", fetch = FetchType.LAZY)
    private Collection<Device> deviceCollection;

    @JoinColumn(name = "CUSTOMER", referencedColumnName = "ID")
    @ManyToOne(fetch = FetchType.LAZY)
    private Customer customer;
    
    /** Creates a new instance of Location */
    public Location() {
    }

    /**
     * Creates a new instance of Location with the specified values.
     * @param id the id of the Location
     */
    public Location(BigDecimal id) {
        this.id = id;
    }

    /**
     * Creates a new instance of Location with the specified values.
     * @param id the id of the Location
     * @param name the name of the Location
     */
    public Location(BigDecimal id, String name) {
        this.id = id;
        this.name = name;
    }

    /**
     * Gets the id of this Location.
     * @return the id
     */
    public BigDecimal getId() {
        return this.id;
    }

    /**
     * Sets the id of this Location to the specified value.
     * @param id the new id
     */
    public void setId(BigDecimal id) {
        this.id = id;
    }

    /**
     * Gets the name of this Location.
     * @return the name
     */
    public String getName() {
        return this.name;
    }

    /**
     * Sets the name of this Location to the specified value.
     * @param name the new name
     */
    public void setName(String name) {
        this.name = name;
    }

    /**
     * Gets the deviceCollection of this Location.
     * @return the deviceCollection
     */
    public Collection<Device> getDeviceCollection() {
        return this.deviceCollection;
    }

    /**
     * Sets the deviceCollection of this Location to the specified value.
     * @param deviceCollection the new deviceCollection
     */
    public void setDeviceCollection(Collection<Device> deviceCollection) {
        this.deviceCollection = deviceCollection;
    }

    /**
     * Gets the customer of this Location.
     * @return the customer
     */
    public Customer getCustomer() {
        return this.customer;
    }

    /**
     * Sets the customer of this Location to the specified value.
     * @param customer the new customer
     */
    public void setCustomer(Customer customer) {
        this.customer = customer;
    }

    /**
     * Returns a hash code value for the object.  This implementation computes 
     * a hash code value based on the id fields in this object.
     * @return a hash code value for this object.
     */
    @Override
    public int hashCode() {
        int hash = 0;
        hash += (this.id != null ? this.id.hashCode() : 0);
        return hash;
    }

    /**
     * Determines whether another object is equal to this Location.  The result is 
     * <code>true</code> if and only if the argument is not null and is a Location object that 
     * has the same id field values as this object.
     * @param object the reference object with which to compare
     * @return <code>true</code> if this object is the same as the argument;
     * <code>false</code> otherwise.
     */
    @Override
    public boolean equals(Object object) {
        // TODO: Warning - this method won't work in the case the id fields are not set
        if (!(object instanceof Location)) {
            return false;
        }
        Location other = (Location)object;
        if (this.id != other.id && (this.id == null || !this.id.equals(other.id))) return false;
        return true;
    }

    /**
     * Returns a string representation of the object.  This implementation constructs 
     * that representation based on the id fields.
     * @return a string representation of the object.
     */
    @Override
    public String toString() {
        return "de.vullriede.lazyLoading.model.Location[id=" + id + "]";
    }
    
}
